/**
 * \file cuesplitter.h
 * Splitter of audio files by cue file
 *
 * \b Project: Qoobar
 * \author Alex Novichkov
 * \date Apr 15 2013
 *
 * Copyright (C) 2013  Alex Novichkov
 *
 * This file is part of Qoobar.
 *
 * Qoobar is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qoobar is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CUESPLITTER_H
#define CUESPLITTER_H

#include <QObject>
#include <QStringList>

class QProcess;
#include <QDateTime>

class CueSplitter : public QObject
{
    Q_OBJECT
public:
    explicit CueSplitter(QObject *parent = 0);
    ~CueSplitter();
    void stop();
    void split();
    QStringList splittedFiles() {return files;}
    QString outputDir() const {return _outputDir;}
    void setOutputDir(const QString &outputDir) {_outputDir = outputDir;}
    QString cueFile() const {return _cueFile;}
    void setCueFile(const QString &cueFile);

signals:
    void message(int type, const QString &text);
    void trackCountChanged(int trackCount);
    void textReady(const QString &text);
    void next();
public slots:
private slots:
    void updateText();
    void outputDirChanged(const QString &);
private:
    void parseCue();
    QProcess *process;
    QString _outputDir;
    QString _cueFile;

    QStringList files;

    QDateTime time;
};

#endif // CUESPLITTER_H
